@@ -1,7 +1,4 @@
 package ChildWithPod;
-our $VERSION = '0.092830';
-
-
 
 use base qw(BaseWithNoPod);
 
@@ -20,4 +17,6 @@ Blah method
 
 sub blah {}
 
+sub zzz { 'Covered by trustme in tests' }
+
 1;
